@@ -115,6 +115,16 @@ class Coins(JSONSerializable, List[Coin_pb]):
         coins = map(Coin.from_data, data)
         return cls(coins)
 
+    @classmethod
+    def from_amino(cls, amino: list) -> Coins:
+        """Converts list of Coin-amino objects to :class:`Coins`.
+
+        Args:
+            amino (list): list of Coin-data objects
+        """
+        coins = map(Coin.from_amino, amino)
+        return cls(coins)
+
     def to_amino(self) -> List[dict]:
         return [coin.to_amino() for coin in self]
 
@@ -149,6 +159,10 @@ class Coins(JSONSerializable, List[Coin_pb]):
         """Creates new set of :class:`Coins` that have ``int`` amounts."""
         return Coins(c.to_int_coin() for c in self)
 
+    def to_int_ceil_coins(self) -> Coins:
+        """Creates a new :class:`Coins` object with all ``int`` coins with ceiling the amount"""
+        return Coins(c.to_int_ceil_coin() for c in self)
+
     def add(self, addend: Union[Coin, Coins]) -> Coins:
         """Performs addition, which combines the sets of Coin objects. Coins of similar denoms
         will be merged into one Coin representing the denom.
