@@ -62,11 +62,11 @@ class ModeInfoSingle(JSONSerializable):
     mode: SignMode = attr.ib()
 
     def to_data(self) -> dict:
-        return {"mode": self.mode}
+        return {"mode": self.mode.name}
 
     @classmethod
     def from_data(cls, data: dict) -> ModeInfoSingle:
-        return cls(data["mode"])
+        return cls(SignMode[data["mode"]])
 
     def to_proto(self) -> ModeInfoSingle_pb:
         return ModeInfoSingle_pb(mode=self.mode)
@@ -104,6 +104,6 @@ class ModeInfoMulti(JSONSerializable):
     @classmethod
     def from_proto(cls, proto: ModeInfoMulti_pb) -> ModeInfoMulti:
         return cls(
-            CompactBitArray.from_proto(proto["bitarray"]),
-            ModeInfo_pb.from_proto(proto["mode_infos"]),
+            CompactBitArray.from_proto(proto.bitarray),
+            ModeInfo_pb.from_proto(proto.mode_infos),
         )
