@@ -13,6 +13,7 @@ from terra_proto.cosmos.crypto.secp256k1 import PubKey as SimplePubKey_pb
 
 from terra_sdk.util.json import JSONSerializable
 
+from ..util.base import create_demux_unpack_any
 from .bech32 import get_bech
 
 BECH32_AMINO_PUBKEY_DATA_PREFIX_SECP256K1 = "eb5ae987" + "21"  # with fixed length 21
@@ -108,6 +109,13 @@ class PublicKey(JSONSerializable, ABC):
             return LegacyAminoMultisigPublicKey.from_data(data)
         raise TypeError("could not unmarshal PublicKey: type is incorrect")
 
+    @classmethod
+    def unpack_any(cls, any_pb: Any_pb):
+        unpack = create_demux_unpack_any(
+            [SimplePublicKey, ValConsPubKey, LegacyAminoMultisigPublicKey]
+        )
+        return unpack(any_pb)
+
     @abstractmethod
     def pack_any(self) -> Any_pb:
         raise NotImplementedError
@@ -143,17 +151,18 @@ class SimplePublicKey(PublicKey):
 
     type_amino = "tendermint/PubKeySecp256k1"
     """"""
-
     type_url = "/cosmos.crypto.secp256k1.PubKey"
     """Normal signature public key type."""
+    prototype = SimplePubKey_pb
+    """"""
 
     key: bytes = attr.ib()
 
     def to_amino(self) -> dict:
-        return {"type": self.type_amino, "value": self.key}
+        return {"type": self.type_amino, "value": base64.b64encode(self.key)}
 
     def to_data(self) -> dict:
-        return {"@type": self.type_url, "key": self.key}
+        return {"@type": self.type_url, "key": base64.b64encode(self.key)}
 
     @classmethod
     def from_data(cls, data: dict) -> SimplePublicKey:
@@ -186,7 +195,7 @@ class SimplePublicKey(PublicKey):
         return address_from_public_key(self)
 
     def address(self) -> str:
-        return get_bech("terra", self.raw_address())
+        return get_bech("terra", self.raw_address().hex())
 
 
 @attr.s
@@ -195,17 +204,18 @@ class ValConsPubKey(PublicKey):
 
     type_amino = "tendermint/PubKeyEd25519"
     """"""
-
     type_url = "/cosmos.crypto.ed25519.PubKey"
     """an ed25519 tendermint public key type."""
+    prototype = ValConsPubKey_pb
+    """"""
 
-    key: str = attr.ib()
+    key: bytes = attr.ib()
 
     def to_amino(self) -> dict:
-        return {"type": self.type_amino, "value": self.key}
+        return {"type": self.type_amino, "value": base64.b64encode(self.key)}
 
     def to_data(self) -> dict:
-        return {"@type": self.type_url, "key": self.key}
+        return {"@type": self.type_url, "key": base64.b64encode(self.key)}
 
     @classmethod
     def from_data(cls, data: dict) -> ValConsPubKey:
@@ -213,7 +223,7 @@ class ValConsPubKey(PublicKey):
 
     @classmethod
     def from_amino(cls, amino: dict) -> ValConsPubKey:
-        return cls(key=base64.b64decode(amino["value"]["key"]))
+        return cls(key=base64.b64decode(amino["value"]))
 
     @classmethod
     def from_proto(cls, proto: ValConsPubKey_pb) -> ValConsPubKey:
@@ -231,11 +241,11 @@ class ValConsPubKey(PublicKey):
     def encode_amino_pubkey(self) -> bytes:
         return bytes.fromhex(BECH32_AMINO_PUBKEY_DATA_PREFIX_ED25519) + bytes(self.key)
 
-    def raw_address(self) -> str:
-        return address_from_public_key(self.key)
+    def raw_address(self) -> bytes:
+        return address_from_public_key(self)
 
     def address(self) -> str:
-        return get_bech("terravalcons", self.raw_address())
+        return get_bech("terravalcons", self.raw_address().hex())
 
 
 @attr.s
@@ -244,9 +254,10 @@ class LegacyAminoMultisigPublicKey(PublicKey):
 
     type_amino = "tendermint/PubKeyMultisigThreshold"
     """"""
-
     type_url = "/cosmos.crypto.multisig.LegacyAminoPubKey"
     """Multisig public key type."""
+    prototype = LegacyAminoPubKey_pb
+    """"""
 
     threshold: int = attr.ib(converter=int)
     public_keys: List[SimplePublicKey] = attr.ib(factory=list)
@@ -271,16 +282,14 @@ class LegacyAminoMultisigPublicKey(PublicKey):
     def from_data(cls, data: dict) -> LegacyAminoMultisigPublicKey:
         return cls(
             threshold=data["threshold"],
-            public_keys=[
-                PublicKey.from_data(pubkey) for pubkey in data["public_keys"]
-            ]
+            public_keys=[PublicKey.from_data(pubkey) for pubkey in data["public_keys"]],
         )
 
     @classmethod
     def from_proto(cls, proto: LegacyAminoPubKey_pb) -> LegacyAminoMultisigPublicKey:
         return cls(
             threshold=proto.threshold,
-            public_keys=[SimplePublicKey.from_proto(pk) for pk in proto.public_keys],
+            public_keys=[PublicKey.unpack_any(pk) for pk in proto.public_keys],
         )
 
     @classmethod
