@@ -15,7 +15,7 @@ from terra_proto.cosmos.staking.v1beta1 import MsgDelegate as MsgDelegate_pb
 from terra_proto.cosmos.staking.v1beta1 import MsgEditValidator as MsgEditValidator_pb
 from terra_proto.cosmos.staking.v1beta1 import MsgUndelegate as MsgUndelegate_pb
 
-from terra_sdk.core import AccAddress, Coin, Dec, ValAddress, ValConsPubKey
+from terra_sdk.core import AccAddress, Coin, Dec, PublicKey, ValAddress, ValConsPubKey
 from terra_sdk.core.msg import Msg
 
 from .data import CommissionRates, Description
@@ -40,7 +40,7 @@ class MsgBeginRedelegate(Msg):
         amount (Union[str, dict, Coin]): coin (LUNA) to redelegate
     """
 
-    type_amino = "staking/MsgBeginRedelegate"
+    type_amino = "cosmos-sdk/MsgBeginRedelegate"
     """"""
     type_url = "/cosmos.staking.v1beta1.MsgBeginRedelegate"
     """"""
@@ -102,7 +102,7 @@ class MsgDelegate(Msg):
         amount (Union[str, dict, Coin]): coin (LUNA) to delegate
     """
 
-    type_amino = "staking/MsgDelegate"
+    type_amino = "cosmos-sdk/MsgDelegate"
     """"""
     type_url = "/cosmos.staking.v1beta1.MsgDelegate"
     """"""
@@ -159,7 +159,7 @@ class MsgUndelegate(Msg):
         amount (Union[str, dict, Coin]): coin (LUNA) to undelegate
     """
 
-    type_amino = "staking/MsgUndelegate"
+    type_amino = "cosmos-sdk/MsgUndelegate"
     """"""
     type_url = "/cosmos.staking.v1beta1.MsgUndelegate"
     """"""
@@ -217,7 +217,7 @@ class MsgEditValidator(Msg):
         min_self_delegation: new minimum self delegation,
     """
 
-    type = "staking/MsgEditValidator"
+    type = "cosmos-sdk/MsgEditValidator"
     """"""
     type_url = "/cosmos.staking.v1beta1.MsgEditValidator"
     """"""
@@ -278,7 +278,7 @@ class MsgCreateValidator(Msg):
         value (Coin.Input): initial amount of Luna toi self-delegate
     """
 
-    type = "staking/MsgCreateValidator"
+    type = "cosmos-sdk/MsgCreateValidator"
     """"""
     type_url = "/cosmos.staking.v1beta1.MsgCreateValidator"
     """"""
@@ -289,7 +289,7 @@ class MsgCreateValidator(Msg):
 
     description: Description = attr.ib()
     commission: CommissionRates = attr.ib()
-    min_self_delegation: int = attr.ib()
+    min_self_delegation: str = attr.ib()
     delegator_address: AccAddress = attr.ib()
     validator_address: ValAddress = attr.ib()
     pubkey: ValConsPubKey = attr.ib()
@@ -314,7 +314,7 @@ class MsgCreateValidator(Msg):
             min_self_delegation=self.min_self_delegation,
             delegator_address=self.delegator_address,
             validator_address=self.validator_address,
-            pubkey=self.pubkey.to_proto(),
+            pubkey=self.pubkey.pack_any(),
             value=self.value.to_proto(),
         )
 
@@ -323,9 +323,9 @@ class MsgCreateValidator(Msg):
         return cls(
             description=Description.from_proto(proto.description),
             commission=CommissionRates.from_proto(proto.commission),
-            min_self_delegation=int(proto.min_self_delegation),
+            min_self_delegation=proto.min_self_delegation,
             delegator_address=proto.delegator_address,
             validator_address=proto.validator_address,
-            pubkey=proto.pubkey,
+            pubkey=PublicKey.unpack_any(proto.pubkey),
             value=Coin.from_proto(proto.value),
         )
