@@ -25,10 +25,12 @@ class SoftwareUpgradeProposal(JSONSerializable):
     description: str = attr.ib()
     plan: Optional[Plan] = attr.ib()
 
-    type_amino = "upgrade/SoftwareUpgradeProposal"
+    type_amino = "cosmos-sdk/SoftwareUpgradeProposal"
     """"""
     type_url = "/cosmos.upgrade.v1beta1.SoftwareUpgradeProposal"
     """"""
+    prototype = SoftwareUpgradeProposal_pb
+    """"""
 
     def to_amino(self) -> dict:
         return {
@@ -72,10 +74,12 @@ class CancelSoftwareUpgradeProposal(JSONSerializable):
     title: str = attr.ib()
     description: str = attr.ib()
 
-    type_amino = "upgrade/CancelSoftwareUpgradeProposal"
+    type_amino = "cosmos-sdk/CancelSoftwareUpgradeProposal"
     """"""
     type_url = "/cosmos.upgrade.v1beta1.CancelSoftwareUpgradeProposal"
     """"""
+    prototype = CancelSoftwareUpgradeProposal_pb
+    """"""
 
     def to_amino(self) -> dict:
         return {
@@ -99,6 +103,7 @@ class CancelSoftwareUpgradeProposal(JSONSerializable):
         return Any_pb(type_url=self.type_url, value=bytes(self.to_proto()))
 
     @classmethod
-    def from_proto(cls, proto: CancelSoftwareUpgradeProposal_pb) -> CancelSoftwareUpgradeProposal:
+    def from_proto(
+        cls, proto: CancelSoftwareUpgradeProposal_pb
+    ) -> CancelSoftwareUpgradeProposal:
         return cls(title=proto.title, description=proto.description)
-
