@@ -4,36 +4,32 @@ from __future__ import annotations
 
 import base64
 import json
+from cProfile import label
 from typing import Optional, Union
 
 import attr
-from terra_proto.terra.wasm.v1beta1 import (
-    MsgClearContractAdmin as MsgClearContractAdmin_pb,
-)
-from terra_proto.terra.wasm.v1beta1 import MsgExecuteContract as MsgExecuteContract_pb
-from terra_proto.terra.wasm.v1beta1 import (
+from betterproto.lib.google.protobuf import Any as Any_pb
+from terra_proto.cosmwasm.wasm.v1 import MsgClearAdmin as MsgClearAdmin_pb
+from terra_proto.cosmwasm.wasm.v1 import MsgExecuteContract as MsgExecuteContract_pb
+from terra_proto.cosmwasm.wasm.v1 import (
     MsgInstantiateContract as MsgInstantiateContract_pb,
 )
-from terra_proto.terra.wasm.v1beta1 import MsgMigrateCode as MsgMigrateCode_pb
-from terra_proto.terra.wasm.v1beta1 import MsgMigrateContract as MsgMigrateContract_pb
-from terra_proto.terra.wasm.v1beta1 import MsgStoreCode as MsgStoreCode_pb
-from terra_proto.terra.wasm.v1beta1 import (
-    MsgUpdateContractAdmin as MsgUpdateContractAdmin_pb,
-)
-from betterproto.lib.google.protobuf import Any as Any_pb
+from terra_proto.cosmwasm.wasm.v1 import MsgMigrateContract as MsgMigrateContract_pb
+from terra_proto.cosmwasm.wasm.v1 import MsgStoreCode as MsgStoreCode_pb
+from terra_proto.cosmwasm.wasm.v1 import MsgUpdateAdmin as MsgUpdateAdmin_pb
 
 from terra_sdk.core import AccAddress, Coins
 from terra_sdk.core.msg import Msg
+from terra_sdk.core.wasm.data import AccessConfig, AccessTypeParam
 from terra_sdk.util.remove_none import remove_none
 
 __all__ = [
     "MsgStoreCode",
-    "MsgMigrateCode",
     "MsgInstantiateContract",
     "MsgExecuteContract",
     "MsgMigrateContract",
-    "MsgUpdateContractAdmin",
-    "MsgClearContractAdmin",
+    "MsgUpdateAdmin",
+    "MsgClearAdmin",
 ]
 
 
@@ -50,89 +46,55 @@ class MsgStoreCode(Msg):
     Args:
         sender: address of sender
         wasm_byte_code: base64-encoded string containing bytecode
+        instantiate_permission: access control to apply on contract creation, optional
     """
 
     type_amino = "wasm/MsgStoreCode"
     """"""
-    type_url = "/terra.wasm.v1beta1.MsgStoreCode"
+    type_url = "/cosmwasm.wasm.v1.MsgStoreCode"
     """"""
     prototype = MsgStoreCode_pb
     """"""
 
     sender: AccAddress = attr.ib()
     wasm_byte_code: str = attr.ib()
-
-    def to_amino(self) -> dict:
-        return {
-            "type": self.type_amino,
-            "value": {"sender": self.sender, "wasm_byte_code": self.wasm_byte_code},
-        }
-
-    @classmethod
-    def from_data(cls, data: dict) -> MsgStoreCode:
-        return cls(sender=data["sender"], wasm_byte_code=data["wasm_byte_code"])
-
-    def to_proto(self) -> MsgStoreCode_pb:
-        return MsgStoreCode_pb(
-            sender=self.sender, wasm_byte_code=base64.b64decode(self.wasm_byte_code)
-        )
-
-    @classmethod
-    def from_proto(cls, proto: MsgStoreCode_pb) -> MsgStoreCode:
-        return cls(sender=proto.sender, wasm_byte_code=base64.b64encode(proto.wasm_byte_code).decode())
-
-
-@attr.s
-class MsgMigrateCode(Msg):
-    """Upload a new smart contract WASM binary to the blockchain, replacing an existing code ID.
-    Can only be called once by creator of the contract, and is used for migrating from Col-4 to Col-5.
-
-    Args:
-        sender: address of sender
-        code_id: reference to the code on the blockchain
-        wasm_byte_code: base64-encoded string containing bytecode
-    """
-
-    type_amino = "wasm/MsgMigrateCode"
-    """"""
-    type_url = "/terra.wasm.v1beta1.MsgMigrateCode"
-    """"""
-    prototype = MsgMigrateCode_pb
-    """"""
-
-    sender: AccAddress = attr.ib()
-    code_id: int = attr.ib(converter=int)
-    wasm_byte_code: str = attr.ib(converter=str)
+    instantiate_permission: AccessConfig = attr.ib()
 
     def to_amino(self) -> dict:
         return {
             "type": self.type_amino,
             "value": {
                 "sender": self.sender,
-                "code_id": str(self.code_id),
                 "wasm_byte_code": self.wasm_byte_code,
+                "instantiate_permission": self.instantiate_permission.to_amino(),
             },
         }
 
     @classmethod
-    def from_data(cls, data: dict) -> MsgMigrateCode:
+    def from_data(cls, data: dict) -> MsgStoreCode:
         return cls(
             sender=data["sender"],
-            code_id=data["code_id"],
             wasm_byte_code=data["wasm_byte_code"],
+            instantiate_permission=AccessConfig.from_data(
+                data["instantiate_permission"]
+            ),
         )
 
-    def to_proto(self) -> MsgMigrateCode_pb:
-        return MsgMigrateCode_pb(
-            sender=self.sender, code_id=self.code_id, wasm_byte_code=base64.b64decode(self.wasm_byte_code)
+    def to_proto(self) -> MsgStoreCode_pb:
+        return MsgStoreCode_pb(
+            sender=self.sender,
+            wasm_byte_code=base64.b64decode(self.wasm_byte_code),
+            instantiate_permission=self.instantiate_permission.to_proto(),
         )
 
     @classmethod
-    def from_proto(cls, proto: MsgMigrateCode_pb) -> MsgMigrateCode:
+    def from_proto(cls, proto: MsgStoreCode_pb) -> MsgStoreCode:
         return cls(
             sender=proto.sender,
-            code_id=proto.code_id,
             wasm_byte_code=base64.b64encode(proto.wasm_byte_code).decode(),
+            instantiate_permission=AccessConfig.from_proto(
+                proto.instantiate_permission
+            ),
         )
 
 
@@ -144,13 +106,14 @@ class MsgInstantiateContract(Msg):
         sender: address of sender
         admin: address of contract admin
         code_id (int): code ID to use for instantiation
-        init_msg (dict|str): InitMsg to initialize contract
-        init_coins (Coins): initial amount of coins to be sent to contract
+        label (str): label for the contract.
+        msg (dict|str): InitMsg to initialize contract
+        funds (Coins): initial amount of coins to be sent to contract
     """
 
     type_amino = "wasm/MsgInstantiateContract"
     """"""
-    type_url = "/terra.wasm.v1beta1.MsgInstantiateContract"
+    type_url = "/cosmwasm.wasm.v1.MsgInstantiateContract"
     """"""
     prototype = MsgInstantiateContract_pb
     """"""
@@ -158,8 +121,9 @@ class MsgInstantiateContract(Msg):
     sender: AccAddress = attr.ib()
     admin: Optional[AccAddress] = attr.ib()
     code_id: int = attr.ib(converter=int)
-    init_msg: Union[dict, str] = attr.ib()
-    init_coins: Coins = attr.ib(converter=Coins, factory=Coins)
+    label: str = attr.ib(converter=str)
+    msg: Union[dict, str] = attr.ib()
+    funds: Coins = attr.ib(converter=Coins, factory=Coins)
 
     def to_amino(self) -> dict:
         return {
@@ -168,8 +132,9 @@ class MsgInstantiateContract(Msg):
                 "sender": self.sender,
                 "admin": self.admin,
                 "code_id": str(self.code_id),
-                "init_msg": remove_none(self.init_msg),
-                "init_coins": self.init_coins.to_amino(),
+                "label": self.label,
+                "msg": remove_none(self.msg),
+                "funds": self.funds.to_amino(),
             },
         }
 
@@ -179,8 +144,9 @@ class MsgInstantiateContract(Msg):
             sender=data.get("sender"),
             admin=data.get("admin"),
             code_id=data["code_id"],
-            init_msg=parse_msg(data["init_msg"]),
-            init_coins=Coins.from_data(data["init_coins"]),
+            label=data["label"],
+            msg=parse_msg(data["msg"]),
+            funds=Coins.from_data(data["funds"]),
         )
 
     def to_proto(self) -> MsgInstantiateContract_pb:
@@ -188,8 +154,9 @@ class MsgInstantiateContract(Msg):
             sender=self.sender,
             admin=self.admin,
             code_id=self.code_id,
-            init_msg=bytes(json.dumps(self.init_msg), "utf-8"),
-            init_coins=self.init_coins.to_proto(),
+            label=self.label,
+            msg=bytes(json.dumps(self.msg), "utf-8"),
+            funds=self.funds.to_proto(),
         )
 
     @classmethod
@@ -198,8 +165,9 @@ class MsgInstantiateContract(Msg):
             sender=proto.sender,
             admin=proto.admin,
             code_id=proto.code_id,
-            init_msg=parse_msg(proto.init_msg),
-            init_coins=Coins.from_proto(proto.init_coins),
+            label=proto.label,
+            msg=parse_msg(proto.msg),
+            funds=Coins.from_proto(proto.funds),
         )
 
 
@@ -210,21 +178,21 @@ class MsgExecuteContract(Msg):
     Args:
         sender: address of sender
         contract: address of contract to execute function on
-        execute_msg (dict|str): ExecuteMsg to pass
+        msg (dict|str): ExecuteMsg to pass
         coins: coins to be sent, if needed by contract to execute.
             Defaults to empty ``Coins()``
     """
 
     type_amino = "wasm/MsgExecuteContract"
     """"""
-    type_url = "/terra.wasm.v1beta1.MsgExecuteContract"
+    type_url = "/cosmwasm.wasm.v1.MsgExecuteContract"
     """"""
     prototype = MsgExecuteContract_pb
     """"""
 
     sender: AccAddress = attr.ib()
     contract: AccAddress = attr.ib()
-    execute_msg: Union[dict, str] = attr.ib()
+    msg: Union[dict, str] = attr.ib()
     coins: Coins = attr.ib(converter=Coins, factory=Coins)
 
     def to_amino(self) -> dict:
@@ -233,7 +201,7 @@ class MsgExecuteContract(Msg):
             "value": {
                 "sender": self.sender,
                 "contract": self.contract,
-                "execute_msg": remove_none(self.execute_msg),
+                "msg": remove_none(self.msg),
                 "coins": self.coins.to_amino(),
             },
         }
@@ -243,25 +211,25 @@ class MsgExecuteContract(Msg):
         return cls(
             sender=data["sender"],
             contract=data["contract"],
-            execute_msg=parse_msg(data["execute_msg"]),
-            coins=Coins.from_data(data["coins"]),
+            msg=parse_msg(data["msg"]),
+            coins=Coins.from_data(data["funds"]),
         )
 
     def to_proto(self) -> MsgExecuteContract_pb:
         return MsgExecuteContract_pb(
             sender=self.sender,
             contract=self.contract,
-            execute_msg=bytes(json.dumps(self.execute_msg), "utf-8"),
-            coins=self.coins.to_proto(),
+            msg=bytes(json.dumps(self.msg), "utf-8"),
+            funds=self.coins.to_proto(),
         )
 
     @classmethod
-    def from_proto(cls, proto: Any_pb) -> MsgExecuteContract:
+    def from_proto(cls, proto: MsgExecuteContract_pb) -> MsgExecuteContract:
         return cls(
             sender=proto.sender,
             contract=proto.contract,
-            execute_msg=parse_msg(proto.execute_msg),
-            coins=Coins.from_proto(proto.coins),
+            msg=parse_msg(proto.msg),
+            coins=(proto.funds),
         )
 
 
@@ -270,80 +238,80 @@ class MsgMigrateContract(Msg):
     """Migrate the contract to a different code ID.
 
     Args:
-        admin: address of contract admin
+        sender: address of contract admin
         contract: address of contract to migrate
-        new_code_id (int): new code ID to migrate to
-        migrate_msg (dict|str): MigrateMsg to execute
+        code_id (int): new code ID to migrate to
+        msg (dict|str): MigrateMsg to execute
     """
 
     type_amino = "wasm/MsgMigrateContract"
     """"""
-    type_url = "/terra.wasm.v1beta1.MsgMigrateContract"
+    type_url = "/cosmwasm.wasm.v1.MsgMigrateContract"
     """"""
     prototype = MsgMigrateContract_pb
     """"""
 
-    admin: AccAddress = attr.ib()
+    sender: AccAddress = attr.ib()
     contract: AccAddress = attr.ib()
-    new_code_id: int = attr.ib(converter=int)
-    migrate_msg: Union[dict, str] = attr.ib()
+    code_id: int = attr.ib(converter=int)
+    msg: Union[dict, str] = attr.ib()
 
     def to_amino(self) -> dict:
         return {
             "type": self.type_amino,
             "value": {
-                "admin": self.admin,
+                "sender": self.sender,
                 "contract": self.contract,
-                "new_code_id": str(self.new_code_id),
-                "migrate_msg": remove_none(self.migrate_msg),
+                "code_id": str(self.code_id),
+                "msg": remove_none(self.msg),
             },
         }
 
     @classmethod
     def from_data(cls, data: dict) -> MsgMigrateContract:
         return cls(
-            admin=data["admin"],
+            sender=data["sender"],
             contract=data["contract"],
-            new_code_id=data["new_code_id"],
-            migrate_msg=parse_msg(data["migrate_msg"]),
+            code_id=data["code_id"],
+            msg=parse_msg(data["msg"]),
         )
 
     def to_proto(self) -> MsgMigrateContract_pb:
         return MsgMigrateContract_pb(
-            admin=self.admin,
+            sender=self.sender,
             contract=self.contract,
-            new_code_id=self.new_code_id,
-            migrate_msg=bytes(json.dumps(self.migrate_msg), "utf-8"),
+            code_id=self.code_id,
+            msg=bytes(json.dumps(self.msg), "utf-8"),
         )
 
     @classmethod
     def from_proto(cls, proto: MsgMigrateContract_pb) -> MsgMigrateContract:
         return cls(
-            admin=proto.admin,
+            sender=proto.sender,
             contract=proto.contract,
-            new_code_id=proto.new_code_id,
-            migrate_msg=parse_msg(proto.migrate_msg),
+            code_id=proto.code_id,
+            msg=parse_msg(proto.msg),
         )
 
 
 @attr.s
-class MsgUpdateContractAdmin(Msg):
+class MsgUpdateAdmin(Msg):
     """Update a smart contract's admin.
 
     Args:
-        admin: address of current admin (sender)
+        sender: address of current admin (sender)
         new_admin: address of new admin
         contract: address of contract to change
     """
 
-    type_amino = "wasm/MsgUpdateContractAdmin"
+    type_amino = "wasm/MsgUpdateAdmin"
     """"""
-    type_url = "/terra.wasm.v1beta1.MsgUpdateContractAdmin"
+    type_url = "/cosmwasm.wasm.v1.MsgUpdateAdmin"
     """"""
-    prototype = MsgUpdateContractAdmin_pb
+    prototype = MsgUpdateAdmin_pb
     """"""
 
-    admin: AccAddress = attr.ib()
+    sender: AccAddress = attr.ib()
     new_admin: AccAddress = attr.ib()
     contract: AccAddress = attr.ib()
 
@@ -351,36 +319,36 @@ class MsgUpdateContractAdmin(Msg):
         return {
             "type": self.type_amino,
             "value": {
-                "admin": self.admin,
+                "sender": self.sender,
                 "new_admin": self.new_admin,
                 "contract": self.contract,
             },
         }
 
     @classmethod
-    def from_data(cls, data: dict) -> MsgUpdateContractAdmin:
+    def from_data(cls, data: dict) -> MsgUpdateAdmin:
         return cls(
-            admin=data["admin"],
+            sender=data["sender"],
             new_admin=data["new_admin"],
             contract=data["contract"],
         )
 
-    def to_proto(self) -> MsgUpdateContractAdmin_pb:
-        return MsgUpdateContractAdmin_pb(
-            admin=self.admin, new_admin=self.new_admin, contract=self.contract
+    def to_proto(self) -> MsgUpdateAdmin_pb:
+        return MsgUpdateAdmin_pb(
+            sender=self.sender, new_admin=self.new_admin, contract=self.contract
         )
 
     @classmethod
-    def from_proto(cls, proto: MsgUpdateContractAdmin_pb) -> MsgUpdateContractAdmin:
+    def from_proto(cls, proto: MsgUpdateAdmin_pb) -> MsgUpdateAdmin:
         return cls(
-            admin=proto.admin,
+            sender=proto.sender,
             new_admin=proto.new_admin,
             contract=proto.contract,
         )
 
 
 @attr.s
-class MsgClearContractAdmin(Msg):
+class MsgClearAdmin(Msg):
     """Clears the contract's admin field.
 
     Args:
@@ -388,35 +356,35 @@ class MsgClearContractAdmin(Msg):
         contract: address of contract to change
     """
 
-    type_amino = "wasm/MsgClearContractAdmin"
+    type_amino = "wasm/MsgClearAdmin"
     """"""
-    type_url = "/terra.wasm.v1beta1.MsgClearContractAdmin"
+    type_url = "/cosmwasm.wasm.v1.MsgClearAdmin"
     """"""
-    prototype = MsgClearContractAdmin_pb
+    prototype = MsgClearAdmin_pb
     """"""
 
-    admin: AccAddress = attr.ib()
+    sender: AccAddress = attr.ib()
     contract: AccAddress = attr.ib()
 
     def to_amino(self) -> dict:
         return {
             "type": self.type_amino,
-            "value": {"admin": self.admin, "contract": self.contract},
+            "value": {"sender": self.sender, "contract": self.contract},
         }
 
     @classmethod
-    def from_data(cls, data: dict) -> MsgClearContractAdmin:
+    def from_data(cls, data: dict) -> MsgClearAdmin:
         return cls(
-            admin=data["admin"],
+            sender=data["sender"],
             contract=data["contract"],
         )
 
-    def to_proto(self) -> MsgClearContractAdmin_pb:
-        return MsgClearContractAdmin_pb(admin=self.admin, contract=self.contract)
+    def to_proto(self) -> MsgClearAdmin_pb:
+        return MsgClearAdmin_pb(sender=self.sender, contract=self.contract)
 
     @classmethod
-    def from_proto(cls, proto: MsgClearContractAdmin_pb) -> MsgClearContractAdmin:
+    def from_proto(cls, proto: MsgClearAdmin_pb) -> MsgClearAdmin:
         return cls(
-            admin=proto.admin,
+            sender=proto.sender,
             contract=proto.contract,
         )
