@@ -1,18 +1,23 @@
-from .base import create_demux, create_demux_proto, create_demux_unpack_any
-
 # core msgs
+from terra_sdk.core.auth import(
+    MsgDonateAllVestingTokens,
+    MsgCreatePeriodicVestingAccount,
+    MsgCreateVestingAccount
+)
 from terra_sdk.core.authz import (
     MsgExecAuthorized,
     MsgGrantAuthorization,
     MsgRevokeAuthorization,
 )
 from terra_sdk.core.bank import MsgMultiSend, MsgSend
+from terra_sdk.core.crisis import MsgVerifyInvariant
 from terra_sdk.core.distribution import (
     MsgFundCommunityPool,
     MsgSetWithdrawAddress,
     MsgWithdrawDelegatorReward,
     MsgWithdrawValidatorCommission,
 )
+from terra_sdk.core.feegrant import MsgGrantAllowance, MsgRevokeAllowance
 from terra_sdk.core.gov.msgs import MsgDeposit, MsgSubmitProposal, MsgVote
 from terra_sdk.core.ibc.msgs import (
     MsgAcknowledgement,
@@ -34,12 +39,6 @@ from terra_sdk.core.ibc.msgs import (
     MsgUpgradeClient,
 )
 from terra_sdk.core.ibc_transfer import MsgTransfer
-from terra_sdk.core.market import MsgSwap, MsgSwapSend
-from terra_sdk.core.oracle import (
-    MsgAggregateExchangeRatePrevote,
-    MsgAggregateExchangeRateVote,
-    MsgDelegateFeedConsent,
-)
 from terra_sdk.core.slashing import MsgUnjail
 from terra_sdk.core.staking import (
     MsgBeginRedelegate,
@@ -49,22 +48,20 @@ from terra_sdk.core.staking import (
     MsgUndelegate,
 )
 from terra_sdk.core.wasm import (
-    MsgClearContractAdmin,
+    MsgClearAdmin,
     MsgExecuteContract,
     MsgInstantiateContract,
-    MsgMigrateCode,
     MsgMigrateContract,
     MsgStoreCode,
-    MsgUpdateContractAdmin,
-)
-from terra_sdk.core.feegrant import (
-    MsgGrantAllowance,
-    MsgRevokeAllowance
-)
-from terra_sdk.core.crisis import (
-    MsgVerifyInvariant
+    MsgUpdateAdmin,
 )
 
+from .base import create_demux, create_demux_proto, create_demux_unpack_any
+auth_msgs = [
+    MsgCreateVestingAccount,
+    MsgCreatePeriodicVestingAccount,
+    MsgDonateAllVestingTokens
+]
 bank_msgs = [MsgSend, MsgMultiSend]
 distribution_msgs = [
     MsgFundCommunityPool,
@@ -73,17 +70,11 @@ distribution_msgs = [
     MsgWithdrawValidatorCommission,
 ]
 gov_msgs = [MsgDeposit, MsgSubmitProposal, MsgVote]
-market_msgs = [MsgSwap, MsgSwapSend]
 authz_msgs = [
     MsgExecAuthorized,
     MsgGrantAuthorization,
     MsgRevokeAuthorization,
 ]
-oracle_msgs = [
-    MsgAggregateExchangeRatePrevote,
-    MsgAggregateExchangeRateVote,
-    MsgDelegateFeedConsent,
-]
 slashing_msgs = [MsgUnjail]
 staking_msgs = [
     MsgBeginRedelegate,
@@ -94,17 +85,13 @@ staking_msgs = [
 ]
 wasm_msgs = [
     MsgStoreCode,
-    MsgMigrateCode,
     MsgInstantiateContract,
     MsgExecuteContract,
     MsgMigrateContract,
-    MsgUpdateContractAdmin,
-    MsgClearContractAdmin,
-]
-feegrant_msgs = [
-    MsgGrantAllowance,
-    MsgRevokeAllowance
+    MsgUpdateAdmin,
+    MsgClearAdmin,
 ]
+feegrant_msgs = [MsgGrantAllowance, MsgRevokeAllowance]
 
 ibc_transfer_msgs = [MsgTransfer]
 ibc_msgs = [
@@ -126,61 +113,56 @@ ibc_msgs = [
     MsgTimeout,
     MsgAcknowledgement,
 ]
-crisis_msgs = [
-    MsgVerifyInvariant
-]
+crisis_msgs = [MsgVerifyInvariant]
 
 parse_msg = create_demux(
     [
+        *auth_msgs,
         *authz_msgs,
         *bank_msgs,
         *distribution_msgs,
         *feegrant_msgs,
         *gov_msgs,
-        *market_msgs,
-        *oracle_msgs,
         *slashing_msgs,
         *staking_msgs,
         *wasm_msgs,
         *ibc_msgs,
         *ibc_transfer_msgs,
-        *crisis_msgs
+        *crisis_msgs,
     ]
 )
 
 parse_proto = create_demux_proto(
     [
+        *auth_msgs,
         *authz_msgs,
         *bank_msgs,
         *distribution_msgs,
         *feegrant_msgs,
         *gov_msgs,
-        *market_msgs,
-        *oracle_msgs,
         *slashing_msgs,
         *staking_msgs,
         *wasm_msgs,
         *ibc_msgs,
         *ibc_transfer_msgs,
-        *crisis_msgs
+        *crisis_msgs,
     ]
 )
 
 
 parse_unpack_any = create_demux_unpack_any(
     [
+        *auth_msgs,
         *authz_msgs,
         *bank_msgs,
         *distribution_msgs,
         *feegrant_msgs,
         *gov_msgs,
-        *market_msgs,
-        *oracle_msgs,
         *slashing_msgs,
         *staking_msgs,
         *wasm_msgs,
         *ibc_msgs,
         *ibc_transfer_msgs,
-        *crisis_msgs
+        *crisis_msgs,
     ]
-)
\ No newline at end of file
+)
